@@ -4,48 +4,32 @@ import (
 	"context"
 	"testing"
 
-	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
-	"golang.org/x/xerrors"
 
+	ftypes "github.com/aquasecurity/fanal/types"
 	"github.com/aquasecurity/trivy-db/pkg/db"
 	dbTypes "github.com/aquasecurity/trivy-db/pkg/types"
 	"github.com/aquasecurity/trivy-db/pkg/utils"
 	"github.com/aquasecurity/trivy-db/pkg/vulnsrc/vulnerability"
+	"github.com/aquasecurity/trivy/pkg/dbtest"
 	"github.com/aquasecurity/trivy/pkg/types"
+	"github.com/stretchr/testify/assert"
 )
 
-func TestClient_FillInfo(t *testing.T) {
+func TestClient_FillVulnerabilityInfo(t *testing.T) {
 	type args struct {
 		vulns      []types.DetectedVulnerability
 		reportType string
 	}
 	tests := []struct {
 		name                    string
-		getSeverity             []db.OperationGetSeverityExpectation
-		getVulnerability        []db.OperationGetVulnerabilityExpectation
+		fixtures                []string
 		args                    args
 		expectedVulnerabilities []types.DetectedVulnerability
 	}{
 		{
-			name: "happy path, with only OS vulnerability but no vendor severity, no NVD",
-			getVulnerability: []db.OperationGetVulnerabilityExpectation{
-				{
-					Args: db.OperationGetVulnerabilityArgs{
-						VulnerabilityID: "CVE-2019-0001",
-					},
-					Returns: db.OperationGetVulnerabilityReturns{
-						Vulnerability: dbTypes.Vulnerability{
-							Title:            "dos",
-							Description:      "dos vulnerability",
-							Severity:         dbTypes.SeverityMedium.String(),
-							References:       []string{"http://example.com"},
-							LastModifiedDate: utils.MustTimeParse("2020-01-01T01:01:00Z"),
-							PublishedDate:    utils.MustTimeParse("2001-01-01T01:01:00Z"),
-						},
-					},
-				},
-			},
+			name:     "happy path, with only OS vulnerability but no vendor severity, no NVD",
+			fixtures: []string{"testdata/fixtures/full.yaml"},
 			args: args{
 				vulns: []types.DetectedVulnerability{
 					{VulnerabilityID: "CVE-2019-0001"},
@@ -68,36 +52,17 @@ func TestClient_FillInfo(t *testing.T) {
 			},
 		},
 		{
-			name: "happy path, with only OS vulnerability but no vendor severity, yes NVD",
-			getVulnerability: []db.OperationGetVulnerabilityExpectation{
-				{
-					Args: db.OperationGetVulnerabilityArgs{
-						VulnerabilityID: "CVE-2019-0001",
-					},
-					Returns: db.OperationGetVulnerabilityReturns{
-						Vulnerability: dbTypes.Vulnerability{
-							Title:       "dos",
-							Description: "dos vulnerability",
-							Severity:    dbTypes.SeverityUnknown.String(),
-							VendorSeverity: dbTypes.VendorSeverity{
-								vulnerability.Nvd: dbTypes.SeverityLow,
-							},
-							References:       []string{"http://example.com"},
-							LastModifiedDate: utils.MustTimeParse("2020-01-01T01:01:00Z"),
-							PublishedDate:    utils.MustTimeParse("2001-01-01T01:01:00Z"),
-						},
-					},
-				},
-			},
+			name:     "happy path, with only OS vulnerability but no vendor severity, yes NVD",
+			fixtures: []string{"testdata/fixtures/full.yaml"},
 			args: args{
 				vulns: []types.DetectedVulnerability{
-					{VulnerabilityID: "CVE-2019-0001"},
+					{VulnerabilityID: "CVE-2019-0002"},
 				},
 				reportType: vulnerability.Ubuntu,
 			},
 			expectedVulnerabilities: []types.DetectedVulnerability{
 				{
-					VulnerabilityID: "CVE-2019-0001",
+					VulnerabilityID: "CVE-2019-0002",
 					Vulnerability: dbTypes.Vulnerability{
 						Title:            "dos",
 						Description:      "dos vulnerability",
@@ -107,89 +72,44 @@ func TestClient_FillInfo(t *testing.T) {
 						PublishedDate:    utils.MustTimeParse("2001-01-01T01:01:00Z"),
 					},
 					SeveritySource: vulnerability.Nvd,
-					PrimaryURL:     "https://avd.aquasec.com/nvd/cve-2019-0001",
+					PrimaryURL:     "https://avd.aquasec.com/nvd/cve-2019-0002",
 				},
 			},
 		},
 		{
-			name: "happy path, with only OS vulnerability but no severity, no vendor severity, no NVD",
-			getVulnerability: []db.OperationGetVulnerabilityExpectation{
-				{
-					Args: db.OperationGetVulnerabilityArgs{
-						VulnerabilityID: "CVE-2019-0001",
-					},
-					Returns: db.OperationGetVulnerabilityReturns{
-						Vulnerability: dbTypes.Vulnerability{
-							Title:       "dos",
-							Description: "dos vulnerability",
-							References:  []string{"http://example.com"},
-						},
-					},
-				},
-			},
+			name:     "happy path, with only OS vulnerability but no severity, no vendor severity, no NVD",
+			fixtures: []string{"testdata/fixtures/full.yaml"},
 			args: args{
 				vulns: []types.DetectedVulnerability{
-					{VulnerabilityID: "CVE-2019-0001"},
+					{VulnerabilityID: "CVE-2019-0003"},
 				},
 				reportType: vulnerability.Ubuntu,
 			},
 			expectedVulnerabilities: []types.DetectedVulnerability{
 				{
-					VulnerabilityID: "CVE-2019-0001",
+					VulnerabilityID: "CVE-2019-0003",
 					Vulnerability: dbTypes.Vulnerability{
 						Title:       "dos",
 						Description: "dos vulnerability",
 						Severity:    dbTypes.SeverityUnknown.String(),
 						References:  []string{"http://example.com"},
 					},
-					PrimaryURL: "https://avd.aquasec.com/nvd/cve-2019-0001",
+					PrimaryURL: "https://avd.aquasec.com/nvd/cve-2019-0003",
 				},
 			},
 		},
 		{
-			name: "happy path, with only OS vulnerability, yes vendor severity, with both NVD and CVSS info",
-			getVulnerability: []db.OperationGetVulnerabilityExpectation{
-				{
-					Args: db.OperationGetVulnerabilityArgs{
-						VulnerabilityID: "CVE-2019-0001",
-					},
-					Returns: db.OperationGetVulnerabilityReturns{
-						Vulnerability: dbTypes.Vulnerability{
-							Title:       "dos",
-							Description: "dos vulnerability",
-							Severity:    dbTypes.SeverityMedium.String(),
-							CweIDs:      []string{"CWE-311"},
-							VendorSeverity: dbTypes.VendorSeverity{
-								vulnerability.RedHat: dbTypes.SeverityLow, // CentOS uses RedHat
-							},
-							CVSS: map[string]dbTypes.CVSS{
-								vulnerability.Nvd: {
-									V2Vector: "(AV:N/AC:L/Au:N/C:P/I:P/A:P)",
-									V2Score:  4.5,
-									V3Vector: "CVSS:3.0/PR:N/UI:N/S:U/C:H/I:H/A:H",
-									V3Score:  5.6,
-								},
-								vulnerability.RedHat: {
-									V2Vector: "AV:N/AC:M/Au:N/C:N/I:P/A:N",
-									V2Score:  7.8,
-									V3Vector: "CVSS:3.0/AV:N/AC:L/PR:N/UI:N/S:U/C:H/I:H/A:H",
-									V3Score:  9.8,
-								},
-							},
-							References: []string{"http://example.com"},
-						},
-					},
-				},
-			},
+			name:     "happy path, with only OS vulnerability, yes vendor severity, with both NVD and CVSS info",
+			fixtures: []string{"testdata/fixtures/full.yaml"},
 			args: args{
 				vulns: []types.DetectedVulnerability{
-					{VulnerabilityID: "CVE-2019-0001"},
+					{VulnerabilityID: "CVE-2019-0004"},
 				},
 				reportType: vulnerability.CentOS,
 			},
 			expectedVulnerabilities: []types.DetectedVulnerability{
 				{
-					VulnerabilityID: "CVE-2019-0001",
+					VulnerabilityID: "CVE-2019-0004",
 					Vulnerability: dbTypes.Vulnerability{
 						Title:       "dos",
 						Description: "dos vulnerability",
@@ -198,7 +118,7 @@ func TestClient_FillInfo(t *testing.T) {
 						References:  []string{"http://example.com"},
 						CVSS: map[string]dbTypes.CVSS{
 							vulnerability.Nvd: {
-								V2Vector: "(AV:N/AC:L/Au:N/C:P/I:P/A:P)",
+								V2Vector: "AV:N/AC:L/Au:N/C:P/I:P/A:P",
 								V2Score:  4.5,
 								V3Vector: "CVSS:3.0/PR:N/UI:N/S:U/C:H/I:H/A:H",
 								V3Score:  5.6,
@@ -212,104 +132,63 @@ func TestClient_FillInfo(t *testing.T) {
 						},
 					},
 					SeveritySource: vulnerability.RedHat,
-					PrimaryURL:     "https://avd.aquasec.com/nvd/cve-2019-0001",
+					PrimaryURL:     "https://avd.aquasec.com/nvd/cve-2019-0004",
 				},
 			},
 		},
 		{
-			name: "happy path light db, with only OS vulnerability, yes vendor severity",
-			getVulnerability: []db.OperationGetVulnerabilityExpectation{
-				{
-					Args: db.OperationGetVulnerabilityArgs{
-						VulnerabilityID: "CVE-2019-0001",
-					},
-					Returns: db.OperationGetVulnerabilityReturns{
-						Vulnerability: dbTypes.Vulnerability{
-							Severity: dbTypes.SeverityMedium.String(),
-							VendorSeverity: dbTypes.VendorSeverity{
-								vulnerability.Ubuntu: dbTypes.SeverityLow,
-							},
-						},
-					},
-				},
-			},
+			name:     "happy path light db, with only OS vulnerability, yes vendor severity",
+			fixtures: []string{"testdata/fixtures/light.yaml"},
 			args: args{
 				vulns: []types.DetectedVulnerability{
-					{VulnerabilityID: "CVE-2019-0001"},
+					{VulnerabilityID: "CVE-2020-0001"},
 				},
 				reportType: vulnerability.Ubuntu,
 			},
 			expectedVulnerabilities: []types.DetectedVulnerability{
 				{
-					VulnerabilityID: "CVE-2019-0001",
+					VulnerabilityID: "CVE-2020-0001",
 					Vulnerability: dbTypes.Vulnerability{
+						Title:    "dos",
 						Severity: dbTypes.SeverityLow.String(),
 					},
 					SeveritySource: vulnerability.Ubuntu,
-					PrimaryURL:     "https://avd.aquasec.com/nvd/cve-2019-0001",
+					PrimaryURL:     "https://avd.aquasec.com/nvd/cve-2020-0001",
 				},
 			},
 		},
 		{
-			name: "happy path light db, with only OS vulnerability, no vendor severity",
-			getVulnerability: []db.OperationGetVulnerabilityExpectation{
-				{
-					Args: db.OperationGetVulnerabilityArgs{
-						VulnerabilityID: "CVE-2020-28928",
-					},
-					Returns: db.OperationGetVulnerabilityReturns{
-						Vulnerability: dbTypes.Vulnerability{
-							VendorSeverity: dbTypes.VendorSeverity{},
-						},
-					},
-				},
-			},
+			name:     "happy path light db, with only OS vulnerability, no vendor severity",
+			fixtures: []string{"testdata/fixtures/light.yaml"},
 			args: args{
 				vulns: []types.DetectedVulnerability{
-					{VulnerabilityID: "CVE-2020-28928"},
+					{VulnerabilityID: "CVE-2020-0002"},
 				},
 				reportType: vulnerability.Alpine,
 			},
 			expectedVulnerabilities: []types.DetectedVulnerability{
 				{
-					VulnerabilityID: "CVE-2020-28928",
+					VulnerabilityID: "CVE-2020-0002",
 					Vulnerability: dbTypes.Vulnerability{
+						Title:    "dos",
 						Severity: dbTypes.SeverityUnknown.String(),
 					},
-					SeveritySource: "",
-					PrimaryURL:     "https://avd.aquasec.com/nvd/cve-2020-28928",
+					PrimaryURL: "https://avd.aquasec.com/nvd/cve-2020-0002",
 				},
 			},
 		},
 		{
-			name: "happy path, with only library vulnerability",
-			getVulnerability: []db.OperationGetVulnerabilityExpectation{
-				{
-					Args: db.OperationGetVulnerabilityArgs{
-						VulnerabilityID: "CVE-2020-0001",
-					},
-					Returns: db.OperationGetVulnerabilityReturns{
-						Vulnerability: dbTypes.Vulnerability{
-							Title:       "COVID-19",
-							Description: "a nasty virus vulnerability for humans",
-							Severity:    dbTypes.SeverityMedium.String(),
-							VendorSeverity: dbTypes.VendorSeverity{
-								vulnerability.PythonSafetyDB: dbTypes.SeverityCritical,
-							},
-							References: []string{"https://www.who.int/emergencies/diseases/novel-coronavirus-2019"},
-						},
-					},
-				},
-			},
+			name:     "happy path, with only library vulnerability",
+			fixtures: []string{"testdata/fixtures/full.yaml"},
 			args: args{
 				vulns: []types.DetectedVulnerability{
-					{VulnerabilityID: "CVE-2020-0001"},
+					{VulnerabilityID: "CVE-2019-0005"},
 				},
-				reportType: "poetry",
+				reportType: ftypes.Poetry,
 			},
 			expectedVulnerabilities: []types.DetectedVulnerability{
 				{
-					VulnerabilityID: "CVE-2020-0001",
+					VulnerabilityID: "CVE-2019-0005",
 					Vulnerability: dbTypes.Vulnerability{
 						Title:       "COVID-19",
 						Description: "a nasty virus vulnerability for humans",
@@ -317,22 +196,13 @@ func TestClient_FillInfo(t *testing.T) {
 						References:  []string{"https://www.who.int/emergencies/diseases/novel-coronavirus-2019"},
 					},
 					SeveritySource: vulnerability.PythonSafetyDB,
-					PrimaryURL:     "https://avd.aquasec.com/nvd/cve-2020-0001",
+					PrimaryURL:     "https://avd.aquasec.com/nvd/cve-2019-0005",
 				},
 			},
 		},
 		{
-			name: "GetVulnerability returns an error",
-			getVulnerability: []db.OperationGetVulnerabilityExpectation{
-				{
-					Args: db.OperationGetVulnerabilityArgs{
-						VulnerabilityID: "CVE-2019-0004",
-					},
-					Returns: db.OperationGetVulnerabilityReturns{
-						Err: xerrors.New("failed"),
-					},
-				},
-			},
+			name:     "GetVulnerability returns an error",
+			fixtures: []string{"testdata/fixtures/sad.yaml"},
 			args: args{
 				vulns: []types.DetectedVulnerability{
 					{VulnerabilityID: "CVE-2019-0004"},
@@ -346,17 +216,15 @@ func TestClient_FillInfo(t *testing.T) {
 
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
-			mockDBConfig := new(db.MockOperation)
-			mockDBConfig.ApplyGetSeverityExpectations(tt.getSeverity)
-			mockDBConfig.ApplyGetVulnerabilityExpectations(tt.getVulnerability)
+			dbtest.InitDB(t, tt.fixtures)
+			defer db.Close()
 
 			c := Client{
-				dbc: mockDBConfig,
+				dbc: db.Config{},
 			}
 
 			c.FillInfo(tt.args.vulns, tt.args.reportType)
 			assert.Equal(t, tt.expectedVulnerabilities, tt.args.vulns, tt.name)
-			mockDBConfig.AssertExpectations(t)
 		})
 	}
 }
@@ -452,9 +320,9 @@ func TestClient_Filter(t *testing.T) {
 		policyFile    string
 	}
 	tests := []struct {
-		name string
-		args args
-		want []types.DetectedVulnerability
+		name      string
+		args      args
+		wantVulns []types.DetectedVulnerability
 	}{
 		{
 			name: "happy path",
@@ -509,7 +377,7 @@ func TestClient_Filter(t *testing.T) {
 				severities:    []dbTypes.Severity{dbTypes.SeverityCritical, dbTypes.SeverityHigh, dbTypes.SeverityUnknown},
 				ignoreUnfixed: false,
 			},
-			want: []types.DetectedVulnerability{
+			wantVulns: []types.DetectedVulnerability{
 				{
 					VulnerabilityID:  "CVE-2018-0001",
 					PkgName:          "bar",
@@ -613,7 +481,7 @@ func TestClient_Filter(t *testing.T) {
 				ignoreUnfixed: false,
 				ignoreFile:    "testdata/.trivyignore",
 			},
-			want: []types.DetectedVulnerability{
+			wantVulns: []types.DetectedVulnerability{
 				{
 					VulnerabilityID:  "CVE-2019-0003",
 					PkgName:          "foo",
@@ -663,7 +531,7 @@ func TestClient_Filter(t *testing.T) {
 				ignoreUnfixed: false,
 				policyFile:    "./testdata/test.rego",
 			},
-			want: []types.DetectedVulnerability{
+			wantVulns: []types.DetectedVulnerability{
 				{
 					VulnerabilityID:  "CVE-2019-0001",
 					PkgName:          "foo",
@@ -755,7 +623,7 @@ func TestClient_Filter(t *testing.T) {
 				severities:    []dbTypes.Severity{dbTypes.SeverityCritical, dbTypes.SeverityHigh, dbTypes.SeverityUnknown},
 				ignoreUnfixed: false,
 			},
-			want: []types.DetectedVulnerability{
+			wantVulns: []types.DetectedVulnerability{
 				{
 					VulnerabilityID:  "CVE-2018-0001",
 					PkgName:          "bar",
@@ -807,10 +675,9 @@ func TestClient_Filter(t *testing.T) {
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
 			c := Client{}
-			got, err := c.Filter(context.Background(), tt.args.vulns, tt.args.severities,
-				tt.args.ignoreUnfixed, tt.args.ignoreFile, tt.args.policyFile)
+			gotVulns, err := c.Filter(context.Background(), tt.args.vulns, tt.args.severities, tt.args.ignoreUnfixed, tt.args.ignoreFile, tt.args.policyFile)
 			require.NoError(t, err)
-			assert.Equal(t, tt.want, got, tt.name)
+			assert.Equal(t, tt.wantVulns, gotVulns)
 		})
 	}
 }
